@@ -318,7 +318,7 @@ void operation_report()
     }                                                        // LCOV_EXCL_STOP
 
     path_list = (char *)sqlite3_column_text(statement, 0);
-    off_t total = sqlite3_column_int64(statement, 1);
+    uint64_t total = sqlite3_column_int64(statement, 1);
 
     if (total >= minimum_file_size) {
 
@@ -329,10 +329,10 @@ void operation_report()
 
       switch (report_format) {
       case REPORT_FORMAT_TEXT:
-        printf("%lu total bytes used by duplicates:\n", (unsigned long)total);
+        printf("%" PRIu64" total bytes used by duplicates:\n", total);
         break;
-      case REPORT_FORMAT_CSV:  printf("%lu,", (unsigned long)total); break;
-      case REPORT_FORMAT_JSON: printf("[ %lu,", (unsigned long)total); break;
+      case REPORT_FORMAT_CSV:  printf("%" PRIu64 ",", total); break;
+      case REPORT_FORMAT_JSON: printf("[ %" PRIu64 ",", total); break;
       }
 
       used += (uint64_t)total;
@@ -361,12 +361,12 @@ void operation_report()
   }
 
   if (report_format == REPORT_FORMAT_TEXT) {
-    unsigned long long kb = used / 1024;
-    unsigned long mb = kb / 1024;
-    unsigned long gb = mb / 1024;
+    uint64_t kb = used / 1024;
+    uint64_t mb = kb / 1024;
+    uint64_t gb = mb / 1024;
 
-    printf("Total used: %" PRIu64 " bytes (%llu KiB, %lu MiB, %lu GiB)\n",
-           used, kb, mb, gb);
+    printf("Total used: %" PRIu64 " bytes (%" PRIu64" KiB, %" PRIu64
+           " MiB, %" PRIu64 " GiB)\n", used, kb, mb, gb);
   }
 
   if (report_format == REPORT_FORMAT_JSON) {
@@ -392,11 +392,11 @@ void operation_report()
  *
  */
 static int file_callback(sqlite3 * dbh,
-                         uint64_t block, ino_t inode, off_t size,
-                         char * path, char * filename, struct direntry * dir_entry)
+                         ino_t inode, uint64_t size,
+                         char * path, char * filename,
+                         struct direntry * dir_entry)
 {
   (void)size;
-  (void)block;
   (void)inode;
   (void)filename;
   (void)dir_entry;
@@ -474,7 +474,7 @@ void operation_file()
 
   sqlite3 * dbh = open_database(db_path, 0);
   init_get_known_duplicates();
-  file_callback(dbh, 0, 0, 0, file_path, NULL, NULL);
+  file_callback(dbh, 0, 0, file_path, NULL, NULL);
   close_database(dbh);
   free_get_known_duplicates();
 }
@@ -496,7 +496,7 @@ void operation_ls()
   init_get_known_duplicates();
   init_scanlist();
   init_dirtree();
-  walk_dir(dbh, start_path[0], NULL, file_callback);
+  walk_dir(dbh, start_path[0], NULL, 0, file_callback);
   close_database(dbh);
   free_get_known_duplicates();
 }
@@ -517,7 +517,7 @@ void operation_uniques()
   init_get_known_duplicates();
   init_scanlist();
   init_dirtree();
-  walk_dir(dbh, start_path[0], NULL, file_callback);
+  walk_dir(dbh, start_path[0], NULL, 0, file_callback);
   close_database(dbh);
   free_get_known_duplicates();
 }
@@ -538,7 +538,7 @@ void operation_dups()
   init_get_known_duplicates();
   init_scanlist();
   init_dirtree();
-  walk_dir(dbh, start_path[0], NULL, file_callback);
+  walk_dir(dbh, start_path[0], NULL, 0, file_callback);
   close_database(dbh);
   free_get_known_duplicates();
 }
